function y_dot = PHPLfunB2(t, y)
% ============================================================================
% 18.385 (Nonlinear Dynamical Systems).    MIT, Fall 1999-2023. R. R. Rosales.
% ____________________________________________________________________________
% y_dot = PHPLfunB2(t, y) calculates f and g for the nonlinear oscilator:
% 
%             dx/dt = f(x,y)     and     dy/dt = g(x,y),
%
% where y = [x, y] and y_dot = [dx/dt, dy/dt].  Notice that, in fact, t plays
% no role here  (it is an argument in the function because ode45 requires the
% argument there).
%
% If glo_dir = -1 (a global variable) then the negatives of the functions are
% evaluated.  This is used to do forward and backward integrations of the ode.
%
% Here I include some examples, but USER IS SUPPOSED TO FILL DESIRED EXAMPLE.
% Notes
%      #1 When writing the function, USE y(1) and y(2); NOT x and y.
%      #2 The figure bounds must be provided, as follows:
%         umax = max value of x;   umin = min value of x;
%         vmax = max value of y;   vmin = min value of y;
%
% The first line in the code selects the example to be used.
% Write your example to fill in the details in example 5; <=============
% Example #3 and 4 show how to include a parameter in the equation to be
%         inputed at run time.
%
% Copyright at the end of this script file.
%
% ============================================================================
example = 5;% Select example to use here.
% ************************************** Global Variables *******************
% TEXTT ....................... title of figure.
% [umin, umax, vmin, vmax] .... figure bounds.
% Rmax2 ....................... switch radius squared: turn-off nonlinearity
%                               to avoid finite time blow-up in solution.
% glo_dir ..................... determines direction of time integration.
% AskForInput ................. Purpose: trigger input command when using the
%                               RegularPHPLdemoB = 0 option.
%
global TEXTT umin umax vmin vmax Rmax2 glo_dir  AskForInput
%
y_dot = y;
%
if example == 1; % Saddle and two centers.
   y_dot(1) = y(2);% ---------------------------- dx/dt = y;
   y_dot(2) = y(1)*(1-y(1)^2);% ----------------- dy/dt = x*(1-x^2);
   TEXTT = 'Saddle and two centers';% ----------- Title
   umin = -2; umax = 2; vmin = -2; vmax = 2;% --- Figure bounds.
%
elseif example == 2; % Limit cycle
   y_dot(1) = y(2);% ---------------------------- dx/dt = y;
   y_dot(2) = -y(1) + y(2)*(1-y(1)^2);% --------- dy/dt = -x + (1-x^2)*y;
   TEXTT = 'Limit cycle';% ---------------------- Title
   umin = -4; umax = 4; vmin = -4; vmax = 4;
%
elseif example == 3;% Parametric limit cycle.
   global glob_mu
   if  AskForInput == 1;   glob_mu = input('   Enter value: mu = ');   end
   r  = norm(y);
   R  = 1 - r^2 + glob_mu*y(1)/(1e-6 + r);
   y_dot(1) = R*y(1)-y(2);% r_dot     = r*(1-r^2) + mu*r*cos(theta);
   y_dot(2) = R*y(2)+y(1);% theta_dot = 1;
   TEXTT = ['Parametric limit cycle;  \mu = ', num2str(glob_mu)];
   umin = -1.25; umax = 3.25; vmin = -1.25; vmax = 3.25;
%
elseif example == 4;% Global limit cycle bifurcation.
   global glob_mu
   if  AskForInput == 1;   glob_mu = input('   Enter value: mu = ');   end
   del = 1+y(1)^2;   mu = glob_mu;
   y_dot(1) = y(2);
   y_dot(2) = 2*mu*y(2) - (1+mu^2)*y(1) + (mu*y(1)-y(2))*y(1)^2;
   y_dot = y_dot/del;
   TEXTT = ['Global limit cycle bifurcation;  \mu = ', num2str(mu)];
   umin = -3; umax = 3; vmin = -3; vmax = 3;
%
elseif example == 5;% My system
   y_dot(1) = y(2);
   y_dot(2) = -y(1);
   TEXTT = 'My system';% ---------------------- Title
   umin = -4; umax = 4; vmin = -4; vmax = 4;
end


% ============================================================================
% ------------------------------------- DO NOT CHANGE ANYTHING BELOW THIS LINE
if glo_dir == -1
   y_dot = - y_dot;
end
% ------------------------------- TURN-OFF the EVOLUTION OUTSIDE PLOTTING AREA
%
% Note that p(x) = (2*x-1)*(x-2)^2 satisfies: p(1)  = 1; p(2)  = 0;
%                                             p'(1) = 0; p'(2) = 0;
% so that it can be used to "turn-off" the equation "smoothly".
%
y2 = y(1)^2+y(2)^2;
if y2 > Rmax2;   p = y2/Rmax2;   y_dot = ((2*p-1)*(p-2)^2)*y_dot;
   if p > 2;   y_dot = 0;   end;   end
% ============================================================================
% Copyright Massachusetts Institute of Technology
% Version 01 by Rodolfo R. Rosales  10-24-1999.
% Version 02 by Rodolfo R. Rosales  10-17-2004.
% Version B2 by Rodolfo R. Rosales  11-10-2023.
% 
% Permission is hereby granted, without payment, to copy this software
% and its documentation, if any,  for non-profit academic and research
% purposes,  provided that the above copyright notice, this paragraph,
% and the following three paragraphs appear in all copies of this
% software. Use of this software constitutes acceptance of these terms
% and conditions.
%
% IN NO EVENT SHALL MIT, OR THE AUTHOR, BE LIABLE TO ANY PARTY FOR
% DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES
% ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN
% IF MIT, OR THE AUTHOR, HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH
% DAMAGE.
%
% MIT, AND THE AUTHOR, SPECIFICALLY DISCLAIM ANY EXPRESS OR IMPLIED
% WARRANTIES INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
% MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
% NON-INFRINGEMENT.
%
% THIS SOFTWARE IS PROVIDED "AS IS." MIT, OR THE AUTHOR, HAVE NO
% OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS,
% OR MODIFICATIONS.
% ============================================================================
% EOF

